[PATCH 2/2] phy: Use _nodev naming convention if non-device clients

Jagan Teki jagan at amarulasolutions.com
Fri May 1 20:14:18 CEST 2020


Clients that are requesting some of uclass API's
without a device (with ofnode) usually have _nodev
naming convention.

- clk_get_by_index_nodev
- clk_get_by_name_nodev
- reset_get_by_index_nodev
- gpio_request_by_name_nodev

So, update the same naming convention PHY framework.

This doesn't change the existing functionality.

Cc: Neil Armstrong <narmstrong at baylibre.com>
Cc: Tom Rini <trini at konsulko.com>
Signed-off-by: Jagan Teki <jagan at amarulasolutions.com>
---
 arch/arm/mach-meson/board-gx.c | 3 ++-
 drivers/phy/phy-uclass.c       | 4 ++--
 include/generic-phy.h          | 7 +++++--
 3 files changed, 9 insertions(+), 5 deletions(-)

diff --git a/arch/arm/mach-meson/board-gx.c b/arch/arm/mach-meson/board-gx.c
index 3da99017a5..b591c924ea 100644
--- a/arch/arm/mach-meson/board-gx.c
+++ b/arch/arm/mach-meson/board-gx.c
@@ -183,7 +183,8 @@ int board_usb_init(int index, enum usb_init_type init)
 
 	/* get the PHYs */
 	for (i = 0; i < 2; i++) {
-		ret = generic_phy_get_by_node(dwc2_node, i, &usb_phys[i]);
+		ret = generic_phy_get_by_index_nodev(dwc2_node, i,
+						     &usb_phys[i]);
 		if (ret && ret != -ENOENT) {
 			pr_err("Failed to get USB PHY%d for %s\n",
 			       i, ofnode_get_name(dwc2_node));
diff --git a/drivers/phy/phy-uclass.c b/drivers/phy/phy-uclass.c
index e463b0b400..8091fc0969 100644
--- a/drivers/phy/phy-uclass.c
+++ b/drivers/phy/phy-uclass.c
@@ -31,7 +31,7 @@ static int generic_phy_xlate_offs_flags(struct phy *phy,
 	return 0;
 }
 
-int generic_phy_get_by_node(ofnode node, int index, struct phy *phy)
+int generic_phy_get_by_index_nodev(ofnode node, int index, struct phy *phy)
 {
 	struct ofnode_phandle_args args;
 	struct phy_ops *ops;
@@ -93,7 +93,7 @@ err:
 int generic_phy_get_by_index(struct udevice *dev, int index,
 			     struct phy *phy)
 {
-	return generic_phy_get_by_node(dev_ofnode(dev), index, phy);
+	return generic_phy_get_by_index_nodev(dev_ofnode(dev), index, phy);
 }
 
 int generic_phy_get_by_name(struct udevice *dev, const char *phy_name,
diff --git a/include/generic-phy.h b/include/generic-phy.h
index e30440d35e..07e4c6f7a0 100644
--- a/include/generic-phy.h
+++ b/include/generic-phy.h
@@ -196,12 +196,15 @@ int generic_phy_get_by_index(struct udevice *user, int index,
 			     struct phy *phy);
 
 /**
  * generic_phy_get_by_node() - Get a PHY device by integer index on ofnode
  *
  * @node:	The client ofnode.
  * @index:	The index in the list of available PHYs
  * @phy:	A pointer to the PHY port
  *
+ * This is a version of generic_phy_get_by_index() that does not use a device.
+ *
  * This looks up a PHY device for a client device based on its ofnode and on
  * its position in the list of the possible PHYs.
  *
@@ -220,7 +223,7 @@ int generic_phy_get_by_index(struct udevice *user, int index,
  *
  * @return 0 if OK, or a negative error code
  */
-int generic_phy_get_by_node(ofnode node, int index, struct phy *phy);
+int generic_phy_get_by_index_nodev(ofnode node, int index, struct phy *phy);
 
 /**
  * generic_phy_get_by_name() - Get a PHY device by its name.
@@ -196,12 +196,15 @@ int generic_phy_get_by_index(struct udevice *user, int index,
 
 /**
- * generic_phy_get_by_node() - Get a PHY device by integer index on ofnode
+ * generic_phy_get_by_index_nodev() - Get a PHY device by integer index
+ * without a device
  *
  * @node:	The client ofnode.
-- 
2.17.1



More information about the U-Boot mailing list